bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 26. Aventiure
___________________________________________________
| ### <Do> si nv waren chomen alle vffe den sant ### der kvenech begonde vragn wer sol vns dvrch daz lant ### di rehten wege wisen daz wir niht irre varn ### do sprach der starche Volker daz sol ich eine bewarn ### Nv enthaltet ivch sprach Hagene ritter vnde chneht ### man sol frivnden volgen ia dvnchet ez mich reht ### vil vngefvegiv mære div tvn ich iv bechant ### wir en chvmen nimmer wider in Bvergonden lant
###### 1585 | ### Daz sageten mir zwei merwip hivte morgen frv ### daz wir niht chomen widere nv rat ich waz man tv ### daz ir ivch waffent helde ir svlt ivch wol bewarn ### wir han hi starche fiende daz wir gewærliche varn
###### 1586 | ### <ich> wande an lvgen finden div wilden merwip ### si iahen daz gesvnder vnser deheines lip ### wider ze lande choeme niwan der kappelan ### dar vmb ich in wolde so gerne hivt ertrenchet han
###### 1587 | ### Do flvgen disiv mære von schare ce shar ### des wrden snelle helde vor leide missevar ### do si begonden sorgen vf den herten [369b] tot ### an dirre hovereise des gie in wærliche not
###### 1588 | ### Da ze moeringen si waren veber chomen ### da dem Elsen vergen der lip was benomen ### do sprach aber Hagene sit daz ich fiende han ### verdienet vf der straze wir werden sicherlich bestan
| ### Ich slvch den selben vergen hivte morgen frv ### si wizen wol div mære nv griffet helde zv ### ob Gelpfrat vnd Else hivte hi beste ### vnser ingesinde daz iz in schædelich erge
###### 1590 | ### Ich erchenne si so chvene ez wirdet niht verlan ### div ross div svlt ir lazen deste sanfter gan ### daz des iemen wane wir vliehen vff den wegen ### des rates wil ich volgen so sprach Giselher der degen
###### 1591 | ### Wer sol daz ingesinde wisen veber lant ### si sprachen daz tvt Volker dem ist ez hie wol bechant ### stige vnd straze der chvene spileman ### ê daz mans vollen gerte man sach gewaffent stan
| ### Den snellen videlære den helm er vff gebant ### in herlicher <varwe> was sin wichgewant ### er bant ovch ce sinem shaffte ein zeichen daz was rot ### sit chom er mit den kvenegen in eine groezliche not
###### 1593 | ### Do was tot des vergen Gelpfrate chomen ### mit gewissem mære do het ez ovch vernomen ### Else der vil starche ez was in beden leit ### si sanden nach ir helden di waren schiere bereit
###### 1594 | ### In vil chvrcen ziten ich wilz ivch hoeren lan ### sach man zv in riten di schaden heten getan ### in starchen verlivgen vil vngefvegiv her ### der chomen Gelpferate wol sibenhvndert oder mer
| ### Do si ir grimmen fienden begonden riten nach ### ia beiten si ir herren den was ein teil ze gach ### nach den chvenen gesten si wolden anden ir zorn ### des wart der herren frivnde sider mer verlorn
###### 1586 | ### Do hete von Tronege Hagene wol gefveget daz ### wi mohte siner mage ein helt gehveten baz ### er pflach der nachhvte mit den sinen man ### vnd Danchwart sin brvder daz was vil wislich getan
###### 1597 | ### In was des tages cervnnen desen heten si niht mer ### er vorhte an sinen vrivnden leit vnde ser ### si riten vnder shilden dvrch der Beyrlant ### da nach in [370a] in chvrcer wile di helde wrden an gerant
| ### Beidenthalp der straze vnd hinden vaste nach ### si horten hveue chlaffen dem livte was ce gach ### do sprach der chvene Danchwart man wil vns hi bestan ### nv bintet vf di helme daz dvnchet mich rætlich getan
###### 1599 | ### Si hielten ab ir verte als iz mvste sin ### si sahen in der finster der liehten schilde schin ### done wolde Hagene niht langer si verdagen ### wer iaget vns vf der straze daz mvs im Gelpfrat do sagen
###### 1600 | ### Do sprach der margrave vz Beyerlant ### wir svchen vnser viende vnde haben her nach gerant ### ine weiz niht wer mir hivte minen vergen slvch ### der was ein helt cen handen des ist mir leide genvch
| ### Do sprach von Tronege Hagen was der verge din ### der wold vns niht fveren des ist div schvlde min ### do slvch ich den recken deiswar des gie mir not ### ich het von sinen handen vil nach gewnnen den tot
###### 1602 | ### Ich bot im ce miete golt vnd gewant ### daz er vns vber fvrte helt in din lant ### do zvrnde er so sere daz er mich do slvch ### mit einer starchen shaltn des was <ih> grimme genvch
###### 1603 | ### Do chom ich cem swerte vnd wert im sinen zorn ### mit einen starchen wnden des wart der helt verlorn ### daz bringe ich iv ce svne swi ivch dvnchet gvt ### do gie ez an ein striten si warn herte gemvt
| ### Ich wesse <wol> sprach Gelpfrat do hi fver gereit ### Gventher vnd sin gesinde daz vns tæte leit ### Hagen von Tronege nv sol er niht genesen ### fver des vergen ende der helt mvz hi pverge wesen
###### 1605 | ### Si neigeten veber schilde ce stichen nv div sper ### Gelpfrat vnd Hagene in was zein ander ger ### Else vnd Danchwart vil herliche riten ### si versvchten wer si waren da wart vil grimme gestriten
###### 1606 | ### Wi moehten sich versvchen immer helde baz ### von einer starchen tioste hinder daz ross gesaz ### Hagen der chven von Gelpfrates hant ### im brast daz fverbvege do wart im striten bechant
| ### Von ir ingesinde der crach der sheffte shal ### do erholt ovch sich do Hagane der ê was ce tal ### chomen von dem stiche nider an daz gras ### er wæne vn [370b] sanftes mvtes wider Gelpfrate was
###### 1608 | ### Wer in div ross behielte daz ist mir vmbechant ### si waren zv der erden <chomen> vf den sant ### Hagen vnd Gelpfrat ein ander lieffen an ### des hvlfen ir gesellen daz in wart striten chvnt getan
###### 1609 | ### Swi pitterliche Hagen ce Gelpfrate <spranch> ### der edel margrave des schildes hin im swanch ### ein michel stvche deiz fiwer dræte dan ### des was vil nach erstorben der chvene Gventheres man
| ### Do begonde er rveffen Danchwarten an ### hilf mir lieber brvder ia hat mich bestan ### ein helt cen sinen handen dern lat mich niht genesen ### do sprach der chven Danchwart des sol ich sheidær wesen
###### 1611 | ### Der helt do spranch dar naher vnd slvch im einen slach ### mit einem sharffen waffen da von er tot gelach ### Else wolde gerne rechen do den man ### er vnd sin gesinde schieden shedeliche dan
###### 1612 | ### Im was erslagen der brvder selbe wart er wnt ### wol ahzech siner degene beliben da cestvnt ### mit dem grimmen tode der herre mvose dan ### flvhtechlichen von den Gventheres man
| ### Do di von Beyerlande wichen vz dem wege ### do hort man nach hellen di vreislichen slege ### do iageten di von Tronege ir fianden nach ### di sin niht enkelten wandn <den> was allen ce gach
###### 1614 | ### Do sprach an der flvehte Danchwart der degen ### wir svln wider wenden balde vf disen wegen ### vnd laze wir si riten si sint von blvte naz ### gahe wir cen frivnden ich rate wærlichen daz
###### 1615 | ### Do si hin wider chomen da der shade was geshehen ### do sprach von Tronege Hagene helde ir svlt besehen ### wes vns hi gebreste oder wen wir han velorn ### hi in disem strite dvrh den Gelpfrades zorn
| ### Si heten vlorn viere di mvsen si verchlagen ### di waren wol vergolten da wider was erslagen ### der von Beyerlande hvndert oder baz ### des waren den von Tronege ir schilde trvebe vnd blvtes naz
###### 1617 | ### Ein teil schein vz den wolchen des liehten manen prêhen ### do sprach aber Hagene niemen sol veriehen ### den minen lieben herren waz wir hi han getan [371a] ### lat siv vnze morgen ane sorge bestan
###### 1618 | ### Do si nv nach in chomen di dort striten ê ### do tet dem ingesinde div mvede harte we ### wi lange svl wir riten sprach manich man ### do sprach der chvene Danchwart wir mvgen niht herberge han
###### 1619 | ### Ir mvezet alle riten vnz ez werde tach ### Volker der snelle der des gesindes pflach ### bat den marshalch vragen wa svl wir hinte sin ### da beraste vnser moere vnd ovch di liebn herren min
| ### Do sprach der chvene Danchwart ine chans iv niht gesagen ### wir enmvegen niht gerwen ê iz beginne tagen ### swa wirz danne vinden da legen vns an ein gras ### do si div mære horten wi leit in svemelichen was
###### 1621 | ### Si beliben vnvermeldet des heizen blvtes rot ### vnz daz div svnne ir liehtez schinen bot ### dem morgen veber berge daz ez der kvenich sach ### daz si gestriten heten der helt vil zornechlichen sprach
###### 1622 | ### Wi nv frivnt Hagene iv wæn versmahet daz ### daz ich piv wære da iv di ringe naz ### svs wrden von dem blvte wer hat daz getan ### er sprach daz tet Else der het vns næhten bestan
| ### Dvrch den sinen vergen wir wrden an gerant ### da slvch Gelpfraten mins brvder Danchwarten hant ### sit entran vns Else des twang in michel not ### in hvndert vnd vns <viere> beliben in dem strite tot
###### 1624 | ### Wir chvnnen niht bescheiden wa si sich leiten nider ### alle di lantlivte di gevriesshen sider ### daz ze hove fvren der edeln Vten chint ### si wrden wol enpfangen da ze Pazowe sint
###### 1625 | ### Der edeln chvenege oeheim der bisshoff <Pilgrim> ### dem wart vil wol ze mvte do di neven sin ### mit also vil recken chomen zv zim in daz lant ### daz er in willech wære daz wart in schier bechant
| ### Si wrden wol enpfangen von vrivnden vf den wegen ### da ze Pazowe man chonde ir niht gepflegen ### si mvsen [371b] veberz wazzer da si fvnden velt ### da wrden vf gespannen hvtten vnde gecelt
###### 1627 | ### Si mvsen da beliben allen einen tach ### vnd ovch di naht mit vollen wi shon man ir pflach ### dar nach si mvsen riten in Rvedegeres lant ### dem wrden ovch div mære dar nach vil schiere bechant
###### 1628 | ### Do di wege mveden rowe genamen ### vnde si dem lande naher quamen ### do fvndens vf der marche slaffende einen man ### dem von Tronege Hagen ein starchez waffen an gewan
| ### Ia was geheizen Eckewart der starche ritter gvt ### er gewan dar vmb einen trvrigen mvt ### da er verlos daz waffen von der helde vart ### di march Rvedegeres di fvndens vebele bewart
###### 1630 | ### Owe mir dirre schande sprach do Eckewart ### ia riwet mich vil sere der Bvrgonden vart ### sit ich Sifride vlos sit was min frevde cergan ### owe herr Rvedger wi han ich wider dich getan
###### 1631 | ### Do hort vil wol Hagene des edelen recken not ### er gab im wider sin waffn vnd sehs povge rot ### di habe dir helt ce minnen daz dv min frivnt sist ### dv bist ein degen chvene swi eine dv vffe der marche list
| ### Got lon iv iwerr povge sprach do Ecchewart ### doch riwet mich vil sere zen Hivnen iwer vart ### ir slvget Sifriden man ist hie gehaz ### daz ir ivch wol behvetet an triwen rat <iv> ich daz
###### 1633 | ### Nv mveze vns got behveten sprach do Hagene ### ian hant niht mere sorge dise degene ### wan vmb di herberge di chvenige vnd ovch ir man ### wa wir in disem lande noch hinte nahtselde han
###### 1634 | ### Div ross sint vns verdorben vf den herten <wegen> ### vnt der spise cervnnen sprach Hagen der degen ### wir finden iz ninder veile vns wære wirtes not ### der vns noch hinte gæbe dvrch sine tvgende sin brot
| ### Do sprach aber Eckwart ich zeih iv einen wirt ### daz ir ce hvse selten [372a] so wol bechomen birt ### in deheinen lande als iv hi mach geschehen ### ob ir vil snelle degene wellet Rvedgern sehen
###### 1636 | ### Der sizet vf der straze vnd ist der beste wirt ### der ie chom ce hvse sin herce tvgende birt ### also der sveze meye daz gras mit blvmen tvt ### swenne er sol helden dienen so ist er vroelich gemvt
###### 1637 | ### Do sprach der kvnech Gventher welt ir min bote sin ### ob vns welle enthalten dvrch den willen min ### min lieber frivnt Rvedger mine mage vnd vnser man ### daz wil <ih> immer dienen so ich aller beste chan
| ### Der bote pin ich gerne sprach do Eckewart ### mit vil gvtem willen hvb er sich an di vart ### vnd sagete do Rvedgere als er het vernomen ### im was in manigen ziten niht so lieber mære chomen
###### 1639 | ### Man sah ce Bechelaren ilen einen degen ### selbe erchande in Rvedger er sprach vf disen wegen ### dort her gahet Eckewart ein Criemhilde man ### er wande daz di viende im heten leide getan
###### 1640 | ### Do gi er fver porten da er den boten vant ### daz swert er ab gvrte vnd leitez von der hant ### div mære div er brahte wrden niht verdaget ### den wirt vnt sine frivnde ez wart in schiere gesaget
| ### Er sprach dem margraven mich hat zv ziv gesant ### Gventher der herre von Bvrgonden lant ### vnd Giselher sin brvder vnd ovch Gernot ### der reckn ieslicher vi sinen dienest her enbot
###### 1642 | ### Daz selbe hat ovch Hagene vnd Voelker ### mit triwen vlizechliche noch sage ich iv mer ### daz iv des kveneges marsshalch bi mir daz enbot ### daz den gvten chnehten wære iwer herberge not
###### 1643 | ### Mit lachendem mvnde antwrte Rvedger ### nv wol mich dirre mære daz di kvenge her ### daz si gervchent miner dieneste der wirt in niht verseit ### choment si mir ce hvse des pin ich vro vnt gemeit
| ### Danchwart der marshalch der hiez ivch wizzen lan ### wen ir ce hvse mit in soldet han ### sehzech sneller recken vnd tvsent ritter gvt ### vnd nivntvsent chnehte do wart er vrolich gemvt
###### 1645 | ### Nv wol mich dirre geste sprach do Rvedeger ### daz mir choment ce hvse [372b] dise geste her ### den ich noch vil selten iht gedienet han ### nv ritet in engegene beide mage vnde man
###### 1646 | ### Do ilten zv den rossen ritter vnd kneht ### swaz in gebot ir herre daz dvhtes alle reht ### do liezen sie in der dienste zogen deste baz ### noch en weste es niht vrov Goetelint div in ir chemenaten saz

<<< Übersicht <<< vorige Seite nächste Seite >>>